==> haskell-data-bword-0.1.0.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-bword
version:              0.1.0.1
visibility:           public
id:                   data-bword-0.1.0.1-dMe7RI0E6sFWIXJGrJrOf
key:                  data-bword-0.1.0.1-dMe7RI0E6sFWIXJGrJrOf
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-bword
synopsis:             Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.

category:             Data
abi:                  8330f9c80c06865993066d006a117dad
exposed:              True
exposed-modules:      Data.BinaryWord
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-bword-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-bword-0.1.0.1
hs-libraries:         HSdata-bword-0.1.0.1-dMe7RI0E6sFWIXJGrJrOf
depends:              base-4.15.0.0 ghc-prim-0.7.0
haddock-interfaces:   /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html:         /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-bword-0.1.0.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-bword
version:              0.1.0.2
visibility:           public
id:                   data-bword-0.1.0.2-5u8kaDShbOR1sqhKauOCS9
key:                  data-bword-0.1.0.2-5u8kaDShbOR1sqhKauOCS9
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-bword
synopsis:             Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.

category:             Data
abi:                  bcde820c2d6bc6beb8bee445f8c99034
exposed:              True
exposed-modules:      Data.BinaryWord
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-bword-0.1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-bword-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-bword
hs-libraries:         HSdata-bword-0.1.0.2-5u8kaDShbOR1sqhKauOCS9
depends:              base-4.15.1.0 ghc-prim-0.7.0
haddock-interfaces:   /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html:         /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
